==> rheolef_6.7.orig.tar.gz: rheolef-6.7/nfem/tst/robin_tst.sh <==
#/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
GEODIR=${GEODIR-"../../../rheolef/nfem/data"}
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

status=0

g=$GEODIR/carre-v2
name=carre

# L="Dir reg cos"
# cos has a problem with doubledouble...
L="Dir reg"

for p in P1 P2; do
  for t in $L; do
    command="./robin_tst -round -app $p -$t $g top bottom left right"
    echo "      $command"
    eval $command 2> /dev/null | diff $SRCDIR/robin-$name-$t-$p.out.valid - >/dev/null
    if test $? -ne 0; then status=1; echo "        => *NO*"; fi
  done
done

exit $status

==> rheolef_7.0.orig.tar.gz: rheolef-7.0/nfem/tst/robin_tst.sh <==
#/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
GEODIR=${GEODIR-"../../../rheolef/nfem/data"}
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

status=0

g=$GEODIR/carre-v2
name=carre

# L="Dir reg cos"
# cos has a problem with bigfloat...
L="Dir reg"

for p in P1 P2; do
  for t in $L; do
    command="./robin_tst -round -app $p -$t $g top bottom left right"
    echo "      $command"
    eval $command 2> /dev/null | diff $SRCDIR/robin-$name-$t-$p.out.valid - >/dev/null
    if test $? -ne 0; then status=1; echo "        => *NO*"; fi
  done
done

exit $status
